// procedural brick texture
// inspired by ch. 6 in the orange book
// GZ, 2014

uniform vec4 BrickColor,         // starting value = (1.0, 0.1, 0.1, 1)  ; don't forget w-coord
             MortarColor;        // starting value = (0.7, 0.7, 0.7, 1)  ; in GlSL_editor!
uniform vec2 BrickStepSize, 
             BrickPercent;       // use start val = 0.8,0.8 for BrickPercent


varying vec4 LightIntensity;     // contains diffuse and specular terms, w/o object color
varying vec2 Pos_mc;             // the position of the vertex/fragment in model(!) coords


void main()
{
	vec2 pos = Pos_mc / BrickStepSize;		// now pos = 0.0,...,1.0 for one brick

	// are we in an odd brick row?
	if ( mod(abs(pos.y), 2.0) > 1.0 )		// this saves conversion to int / mod
		pos.x += 0.5;

	pos = fract( pos );                       // = rel. position within brick
	
	// determine color
	vec4 color;
	if ( any( greaterThan(pos, BrickPercent) ) )	// now with vector relational functions
		color = MortarColor;
	else
		color = BrickColor;

	color *= LightIntensity;
    gl_FragColor = color;
}
