// Procedural brick texture; brick 2
// inspired by ch. 6 in the orange book
// GZ, 2014
// http://shaderfrog.com/app/view/5295


// Set the precision for data types used in this shader
precision mediump float;
precision mediump int;

uniform vec2 BrickStepSize;         // MUST NOT BE 0! use starting value = 0.2 , 0.2
uniform vec2 BrickPercent;          // 
uniform vec3 BrickColor;            // starting value = (1.0, 0.1, 0.1)
uniform vec3 MortarColor;           // 0.7, 0.7, 0.7
// DO NOT use declarations like:  uniform vec2 BrickStepSize, BrickPercent;  !!

uniform float ambient;
             
// Default THREE.js uniforms available to both fragment and vertex shader
uniform mat4 modelMatrix;
uniform mat4 modelViewMatrix;
uniform mat4 projectionMatrix;
uniform mat4 viewMatrix;
uniform mat3 normalMatrix;


//  varyings passed from the vertex shader
varying vec3 vPosition_model;     // the position of the vertex/fragment in model(!) coords
varying vec3 vNormal_model;
varying vec3 vPosition_world;
varying vec3 vNormal_world;

// new: lighting from vertex shader
varying float brightness;



void main()
{

	vec2 rel_pos = vPosition_model.xy / BrickStepSize;	  // now pos in [k,k+1] for one brick

    // are we in an odd brick row?
    if ( mod(abs(rel_pos.y), 2.0) > 1.0 )     // this saves conversion to int / mod
        rel_pos.x += 0.5;

    rel_pos = fract( rel_pos );                   // = rel. position within brick
    
    // new: determine color
    vec3 color;
    if ( rel_pos.x > BrickPercent.x || rel_pos.y > BrickPercent.y )
        color = MortarColor;
    else
        color = BrickColor;
    
    gl_FragColor = vec4( clamp( (brightness), 0.0, 1.0)  * color , 1.0);
    //gl_FragColor = vec4( color, 1.0);
}

