// Procedural brick texture; brick 4
// inspired by ch. 6 in the orange book
// GZ, 2014
// http://shaderfrog.com/app/view/5296


precision highp float;
precision highp int;

// new: inclue noise
uniform float noise_spatial_freq;	// spatial frequency of the noise; start with 0.9
uniform float noise_amplitude;		// 0.2
uniform float noise_shift;		    // doesn't make sense here, but included for demo purposes

uniform vec2 BrickStepSize;         // MUST NOT BE 0! use starting value = 0.2 , 0.2
uniform vec2 BrickPercent;          // 0.9, 0.8
uniform vec3 BrickColor;            // starting value = (1.0, 0.1, 0.1)
uniform vec3 MortarColor;           // 0.7, 0.7, 0.7
// DO NOT use declarations like:  uniform vec2 BrickStepSize, BrickPercent;  !!

uniform float ambient;              // ambient light;  start: 0.5

// Default uniforms provided by ShaderFrog
uniform float time;

// Default THREE.js uniforms available to both fragment and vertex shader
uniform mat4 modelMatrix;
uniform mat4 modelViewMatrix;
uniform mat4 projectionMatrix;
uniform mat4 viewMatrix;
uniform mat3 normalMatrix;

//  varyings passed from the vertex shader
varying vec3 vPosition_model;     // the position of the vertex/fragment in model(!) coords
varying vec3 vNormal_model;
varying vec3 vPosition_world;
varying vec3 vNormal_world;

varying float brightness;



// new: home-grown noise functions
// definitely not perfect, not stable due to extreme sensitivity to input values
// stolen from https://stackoverflow.com/questions/4200224/random-noise-functions-for-glsl

float phi = 1.61803398874989484820459 * 00000.1; // Golden Ratio   
float pi  = 3.14159265358979323846264 * 00000.1; // PI
float srt = 1.41421356237309504880169 * 10000.0; // Square Root of Two

float random_0t1(in vec2 coordinate, in float seed)
{
    return fract( sin( dot(coordinate*seed, vec2(phi, pi)) ) * srt );
}

float noise1( in vec2 v )
{
    return random_0t1( v, 1.0 );                        // don't use time, otherwise the noise artifacts will change over time
}

vec3 noise3( in vec2 v )
{
    return vec3( random_0t1( v, 2.0 ),
                 random_0t1( v, 5.0 ),
                 random_0t1( v, 9.0 )  );
}




void main()
{

	vec2 rel_pos = vPosition_model.xy / BrickStepSize;	  // now pos in [k,k+1] for one brick

    // are we in an odd brick row?
    if ( mod(abs(rel_pos.y), 2.0) > 1.0 )           // this saves conversion to int / mod
        rel_pos.x += 0.5;

    rel_pos = fract( rel_pos );                     // = rel. position within brick
    
    // new: include noise
    vec3 color;
    vec3 dirt;
	if ( any( greaterThan(rel_pos, BrickPercent) ) )
	{
		color = MortarColor;
		// add some "dirt"
		float c = noise_amplitude * noise1( noise_spatial_freq * vPosition_model.xy + 
									  vec2(noise_shift) );
		dirt = vec3( c, c, c );
	}
	else
	{
		color = BrickColor;
		// add some "dirt"
		vec3 c = noise_amplitude * noise3( noise_spatial_freq * vPosition_model.xy + 
									  vec2(noise_shift) );
		dirt = c;	
	}
	color += dirt;
    
    color *= clamp( brightness, 0.0, 1.0);
    gl_FragColor = vec4( color , 1.0);
}


