#version 330 core

// 
// lighting1.vert
//
// Run with ShaderMaker
//
// This set of shaders (lighting[1-3].{vert,frag}) shows 
// per-pixel lighting step-by-step
//
// Author: GZ, 2007, 2012, 2019


struct LightSource {
	vec3 direction;
	vec3 color;
};

// Parameters pre-defined by ShaderMaker (as uniforms)
uniform mat4 viewMatrix;   // view matrix of the model
uniform mat4 projection;   // projection matrix (depends on aspect ratio of window)

// Attributes per vertex
in vec3 vPosition;         // xyz position of the vertex
in vec3 vNormal;           // xyz normal of the vertex

// Attributes to be calculated by this shader, for following fragment shader
out vec3 vColor;           // color value at a specific vertex


void main()
{
	LightSource light1;
	light1.direction = vec3(1, 1, 1);       // we define the direction directly in camera coord
	light1.color = vec3(1, 1, 1);
	vec3 kd = vec3( 1, 1, 0 );	            // reflection coefficients
	vec3 ks = vec3( 0, 0, 1 );
	vec3 ambient = vec3( 0.2, 0.2, 0.2 );   // ambient light

	// Transform the normal into eye space and normalize the result
	// We can use the viewing matrix here, because ShaderMaker uses only rigid transformations
	vec3 normal = normalize( viewMatrix * vec4(vNormal, 0.0) ).xyz;

	// Now normalize the light vector. Note: we assume that light's
	// direction is already given in eye space!
	vec3 lightDir = normalize( light1.direction );
	
	// Compute the cos of the angle between the normal and lights
	// direction.  The light is directional so the direction is
	// constant for every vertex.  Since these two are normalized,
	// the cosine is the dot product. We also need to clamp the
	// result to the [0,1] range.
	float NdotL = max( dot(normal, lightDir), 0.0 );

	// Compute the diffuse term
	vColor =  NdotL * kd * light1.color + ambient;

	vec4 vpos_cam_space = viewMatrix * vec4(vPosition, 1.0);
	gl_Position = projection * vpos_cam_space;
}

