#version 330 core

// 
// lighting3.frag
//
// Run with ShaderMaker
//
// This set of shaders (lighting[1-3].{vert,frag}) shows 
// per-pixel lighting step-by-step
//
// Author: GZ, 2007, 2012, 2019
 

// Attributes per fragment, coming in from rasterizer
in vec3 half_vector;           // half vector (interpolated by rasterizer)
in vec3 normal;                // normal per fragment
flat in vec3 light_dir;        // we can use 'flat', because it's a direction

// Output of fragment shader
out vec3 fragColor;	           // fragment color (the sole output of the fragment shader)


void main()
{
	// define light source and material (normally, this would be done via uniforms)
	vec3 light_color = vec3(1, 1, 1);		                      // white
	vec3 kd = vec3( 0.7, 0.7, 0 );                                // reflection coefficients
	vec3 ks = vec3( 0, 0, 0.7 );                                  
	float shininess = 50;

	vec3 color = vec3( 0.2, 0.2, 0.2 );                           // init color with ambient light

	// do the normalizations here, becasue the rasterizer doesn't do it
	vec3 unit_light_dir = normalize( light_dir );
	vec3 unit_normal = normalize( normal );
	vec3 unit_half_vector = normalize( half_vector );             // very necessary!

	// Compute the diffuse term
	float NdotL = max( dot(unit_normal, unit_light_dir), 0.0 );
	color +=  NdotL * kd * light_color;

	// Compute the specular term
	// Note: blue highlight with yellow base color will yield white
	float NdotH = max( dot(unit_normal, unit_half_vector), 0.0 );
	color += pow(NdotH, shininess) * ks * light_color;

	// Note: we "should" take care about RGB values > 1!

	fragColor = color;
}

