#version 330 core


// Ein Shader, der sog. "Toon Shading" macht, d.h., die Objekte so
// darstellt, dass sie aehnlich wie in einem Cartoon aussehen (hence the name)
//
// ACHTUNG: dieser Shader nimmt eine "directional light source" an!
// (Der Shader toon2,{vert,frag} ist generisch programmiert, so dass er mit
// positional als auch directional light source zurecht kommt.)
//
// GZ 2011
// PD 2017


uniform vec4 LightSource;

// Mit dieser uniform-Variable koennen wir aus dem Shader-Editor die Grundfarbe
// des Toon-Shadings setzen.

uniform vec3 Color;

// Kommt vom Rasterizer bzw. Vertex-Shader
in vec3 fNormal;

// Output attribute
out vec4 FragColor;


void main()
{
	// Berechne Vektor zur Lichtquelle (wir nehmen Richtungslichtquelle an)
	vec3 l = normalize( LightSource.xyz );

	// Normiere Normale (durch Interpolation im Rasterizer kann Laenge ungleich 1 werden)
	vec3 n = normalize( fNormal );

	// Setze Helligkeit fuer dieses Pixel abhaengig vom Winkel zwischen
	// Lichtvektor und Normale (wie diffuser Term bei Phong)
	float intensity = dot( l, n );

	vec4 c;
	if (intensity > 0.95)			          // ... aber in diskreten Levels
		c = vec4( Color, 1.0 );
	else if (intensity > 0.8)
		c = vec4( 0.7*Color, 1.0 );
	// else if (intensity > 0.6)
		// c = vec4( 0.8* vec3(Color.rg, 1.0), 1.0 );
	else if (intensity > 0.4)
		c = vec4( 0.3*Color, 1.0 );
	else
		c = vec4( 0.1*Color, 1.0 );

	FragColor = c;
}

